radontea
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|

Algorithms to compute the inverse Radon transform (e.g. SART,
backprojection, Fourier interpolation).


Documentation
-------------
The documentation, including the reference and examples, is available at
`radontea.readthedocs.io <https://radontea.readthedocs.io/en/stable/>`__.


Installation
------------
The package can be installed from the Python package index::

    pip install radontea


Testing
-------
Some functionalities of the module are tested with::

    pip install pytest
    pytest tests



.. |PyPI Version| image:: https://img.shields.io/pypi/v/radontea.svg
   :target: https://pypi.python.org/pypi/radontea
.. |Tests Status| image:: https://img.shields.io/github/workflow/status/RI-Imaging/radontea/Checks
   :target: https://github.com/RI-Imaging/radontea/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/radontea/master.svg
   :target: https://codecov.io/gh/RI-imaging/radontea
.. |Docs Status| image:: https://readthedocs.org/projects/radontea/badge/?version=latest
   :target: https://readthedocs.org/projects/radontea/builds/
